// =============================================================================
// Message.h: Declarations of class cMessage
// Filter application, (c) lars.staurset@statkart.no 2003
// Purpose: Handle a message
// =============================================================================

#pragma once
#include "MessageHeader.h"
#include "Part.h"

class cMessage
{
    // =========================================================================
    // Public functions
    // =========================================================================
public:
    // ---------------------------------------------------------------------------
    // Class administration (construction, destruction, etc.)
    // ---------------------------------------------------------------------------
    cMessage (
        cOutStream *,     // Stream to be written
        const OutputLevel);     // Output level, see Typedefs.h
    ~cMessage(void);

    // ---------------------------------------------------------------------------
    // Data processing
    // ---------------------------------------------------------------------------
    // Process a line from the input stream
    // Success: A line was processed as appropriate
    // Failure: May throw a cException
    void ProcessLine (
        const string);          // Line to be added

    // Get some information
    int GetPartCount() { return m_nPartCount; }
    int GetRemovedPartCount() { return m_nRemovedPartCount; }
    bool GetDeleted() { return m_bDeleted; }

    // =========================================================================
    // Private functions
    // =========================================================================

    // Process a message header line
    // Success: Line is saved in buffer
    // If end of header is found, the header vill be analyzed
    // Failure: Throws a cException on file errors
    void ProcessHeaderLine (const string);

    // Process final boundary (message terminator)
    // Success: Finishes handling of current message
    // Failure: Throws a cException on file errors
    void ProcessFinalBoundary (const string);

    // Process part boundary
    // Success: Finishes any current part and starts a new one
    // Failure: Throws a cException on file errors
    void ProcessPartBoundary (const string);

    // =========================================================================
    // Private data members
    // =========================================================================
private:
    // ---------------------------------------------------------------------------
    // Members passed from client class
    // ---------------------------------------------------------------------------
    cOutStream *m_pOutStream;   // Outstream object
    OutputLevel m_eOutputLevel;     // Output level, see Typedefs.h

    // ---------------------------------------------------------------------------
    // Members proper to this class
    // ---------------------------------------------------------------------------
    bool m_bDeleted;            // Message deleted?
    bool m_bInMessageHeader;    // In message header?
    string m_sBoundary;         // Boundary that separates parts of message
    bool m_bFoundBoundary;      // Boundary already encountered?
    ContentType m_eContentType; // Content-Type
    int m_nPartCount;           // Count of parts
    int m_nRemovedPartCount;    // Count of removed parts in current message
    cMessageHeader *m_pMessageHeader;   // Pointer to cMessageHeader object
    cPart *m_pPart;             // Pointer to cPart object
};
