// =============================================================================
// MessageHeader.h: Declarations of class cMessageHeader
// Filter application, (c) lars.staurset@statkart.no 2003
// Purpose: Handle message headers
// =============================================================================

#pragma once
#include "Typedefs.h"
#include "Header.h"

class cMessageHeader : public cHeader
{
    // =========================================================================
    // Public functions
    // =========================================================================
public:
    // ---------------------------------------------------------------------------
    // Class administration (construction, destruction, etc.)
    // ---------------------------------------------------------------------------
    cMessageHeader (
        const OutputLevel);     // Output level, see Typedefs.h
    ~cMessageHeader ();

    // ---------------------------------------------------------------------------
    // Data processing
    // ---------------------------------------------------------------------------

    // Process a header line
    // Success: Like cHeader::ProcessLine but this one also checks for deleted message
    // Failure: N/A
    bool ProcessLine (          // return true if more input is expected
        const string);              // Line to be processed

    // Analyze a message header when all lines have been read
    // Success: Finds boundary, Content-Type and other information
    // Failure: Throws a cException on unknown format
    void Analyze ();

    // Inform caller whether message is deleted
    bool Deleted () const { return m_bDeleted; };

    // Get boundary string that separates parts of message
    // Only to be called after Analyze
    string GetBoundary() const { return m_sBoundary; }

    // Get Content-Type
    // Only to be called after Analyze
    ContentType GetContentType() { return m_eContentType; }

    // =========================================================================
    // Private functions
    // =========================================================================
private:
    // Display some info from a header line
    void Display (
        const string,           // Line in lower-case
        const string)           // Line in original case
        const;

    // Determine whether current line indicates deletes message
    // Success: Makes m_bDeleted true if 'deleted' flag is found
    void SetDeleted (
        const string);          // Line

    // Look for hex value in current line
    // Success: If line starts with key, extract hex value that follows key
    bool GetHex (           // Return true if value found
        const string,           // Line
        const string,           // Key
        unsigned long *)        // Value, unchanged if key not found
        const;

    // =========================================================================
    // Private data members
    // =========================================================================
private:
    bool m_bDeleted;            // True if message was deleted
    ContentType m_eContentType; // Content-Type
    string m_sBoundary;         // Boundary between parts
};
